==> igniteui-react-core-18.2.0-beta.2.tgz: package/esm5/lib/WebGridRowEditActionsTemplateContextDescriptionMetadata.js <==
/*
THIS INFRAGISTICS ULTIMATE SOFTWARE LICENSE  AGREEMENT ("AGREEMENT") LOCATED HERE:
https://www.infragistics.com/legal/license/igultimate-la
https://www.infragistics.com/legal/license/igultimate-eula
GOVERNS THE LICENSING, INSTALLATION AND USE OF INFRAGISTICS SOFTWARE. BY DOWNLOADING AND/OR INSTALLING AND USING INFRAGISTICS SOFTWARE:  you are indicating that you have read and understand this Agreement, and agree to be legally bound by it on behalf of the yourself and your company.
*/
import { __extends } from "tslib";
import { Base, String_$type, markType } from "./type";
import { Dictionary$2 } from "./Dictionary$2";
import { WebGridRowEditActionsTemplateContextDescription } from "./WebGridRowEditActionsTemplateContextDescription";
/**
 * @hidden
 */
var WebGridRowEditActionsTemplateContextDescriptionMetadata = /** @class */ /*@__PURE__*/ (function (_super) {
    __extends(WebGridRowEditActionsTemplateContextDescriptionMetadata, _super);
    function WebGridRowEditActionsTemplateContextDescriptionMetadata() {
        return _super !== null && _super.apply(this, arguments) || this;
    }
    WebGridRowEditActionsTemplateContextDescriptionMetadata.b = function (a) {
        if (WebGridRowEditActionsTemplateContextDescriptionMetadata.a == null) {
            WebGridRowEditActionsTemplateContextDescriptionMetadata.a = new Dictionary$2(String_$type, String_$type, 0);
            WebGridRowEditActionsTemplateContextDescriptionMetadata.c(WebGridRowEditActionsTemplateContextDescriptionMetadata.a);
        }
        if (a.k(WebGridRowEditActionsTemplateContextDescriptionMetadata.a)) {
            return;
        }
        a.ab(WebGridRowEditActionsTemplateContextDescriptionMetadata.a);
    };
    WebGridRowEditActionsTemplateContextDescriptionMetadata.c = function (a) {
        a.item("__qualifiedNameTS", "String:GridRowEditActionsTemplateContext");
        a.item("__packageNameWC", "String:grids");
        a.item("__skipModuleRegisterWebComponents", "Boolean");
        a.item("__importOverrideWebComponents", "String:igniteui-webcomponents-grids/grids/combined");
        a.item("__importTypesWebComponents", "String:igniteui-webcomponents-grids/grids");
        a.item("__isPlainObject", "Boolean");
        a.item("__skipSuffix", "Boolean");
    };
    WebGridRowEditActionsTemplateContextDescriptionMetadata.d = function (a) {
        WebGridRowEditActionsTemplateContextDescriptionMetadata.b(a);
        a.ad("WebGridRowEditActionsTemplateContext", function () { return new WebGridRowEditActionsTemplateContextDescription(); });
        a.ac("WebGridRowEditActionsTemplateContext", WebGridRowEditActionsTemplateContextDescriptionMetadata.a);
    };
    WebGridRowEditActionsTemplateContextDescriptionMetadata.$t = markType(WebGridRowEditActionsTemplateContextDescriptionMetadata, 'WebGridRowEditActionsTemplateContextDescriptionMetadata');
    WebGridRowEditActionsTemplateContextDescriptionMetadata.a = null;
    return WebGridRowEditActionsTemplateContextDescriptionMetadata;
}(Base));
export { WebGridRowEditActionsTemplateContextDescriptionMetadata };

==> igniteui-react-core-18.7.0-beta.2.tgz: package/esm5/lib/WebGridRowEditActionsTemplateContextDescriptionMetadata.js <==
/*
THIS INFRAGISTICS ULTIMATE SOFTWARE LICENSE  AGREEMENT ("AGREEMENT") LOCATED HERE:
https://www.infragistics.com/legal/license/igultimate-la
https://www.infragistics.com/legal/license/igultimate-eula
GOVERNS THE LICENSING, INSTALLATION AND USE OF INFRAGISTICS SOFTWARE. BY DOWNLOADING AND/OR INSTALLING AND USING INFRAGISTICS SOFTWARE:  you are indicating that you have read and understand this Agreement, and agree to be legally bound by it on behalf of the yourself and your company.
*/
import { __extends } from "tslib";
import { Base, String_$type, markType } from "./type";
import { Dictionary$2 } from "./Dictionary$2";
import { WebGridRowEditActionsTemplateContextDescription } from "./WebGridRowEditActionsTemplateContextDescription";
/**
 * @hidden
 */
var WebGridRowEditActionsTemplateContextDescriptionMetadata = /** @class */ /*@__PURE__*/ (function (_super) {
    __extends(WebGridRowEditActionsTemplateContextDescriptionMetadata, _super);
    function WebGridRowEditActionsTemplateContextDescriptionMetadata() {
        return _super !== null && _super.apply(this, arguments) || this;
    }
    WebGridRowEditActionsTemplateContextDescriptionMetadata.b = function (a) {
        if (WebGridRowEditActionsTemplateContextDescriptionMetadata.a == null) {
            WebGridRowEditActionsTemplateContextDescriptionMetadata.a = new Dictionary$2(String_$type, String_$type, 0);
            WebGridRowEditActionsTemplateContextDescriptionMetadata.c(WebGridRowEditActionsTemplateContextDescriptionMetadata.a);
        }
        if (a.k(WebGridRowEditActionsTemplateContextDescriptionMetadata.a)) {
            return;
        }
        a.ac(WebGridRowEditActionsTemplateContextDescriptionMetadata.a);
    };
    WebGridRowEditActionsTemplateContextDescriptionMetadata.c = function (a) {
        a.item("__qualifiedNameTS", "String:GridRowEditActionsTemplateContext");
        a.item("__packageNameWC", "String:grids");
        a.item("__skipModuleRegisterWebComponents", "Boolean");
        a.item("__importOverrideWebComponents", "String:igniteui-webcomponents-grids/grids/combined");
        a.item("__importTypesWebComponents", "String:igniteui-webcomponents-grids/grids");
        a.item("__marshalByValue", "Boolean");
        a.item("__skipSuffix", "Boolean");
        a.item("ImplicitRef", "(w:Implicit,wf:Implicit)MethodRef");
    };
    WebGridRowEditActionsTemplateContextDescriptionMetadata.d = function (a) {
        WebGridRowEditActionsTemplateContextDescriptionMetadata.b(a);
        a.ae("WebGridRowEditActionsTemplateContext", function () { return new WebGridRowEditActionsTemplateContextDescription(); });
        a.ad("WebGridRowEditActionsTemplateContext", WebGridRowEditActionsTemplateContextDescriptionMetadata.a);
    };
    WebGridRowEditActionsTemplateContextDescriptionMetadata.$t = markType(WebGridRowEditActionsTemplateContextDescriptionMetadata, 'WebGridRowEditActionsTemplateContextDescriptionMetadata');
    WebGridRowEditActionsTemplateContextDescriptionMetadata.a = null;
    return WebGridRowEditActionsTemplateContextDescriptionMetadata;
}(Base));
export { WebGridRowEditActionsTemplateContextDescriptionMetadata };
